Kas ir OiRA? | OiRA

Temati

# Kas ir OiRA?

## Neesat pazīstams ar OiRA?

Šeit ir īss ievads par riska novērtējumu un to, kā OiRA var jums palīdzēt to pārvaldīt.

## Kas ir riska novērtējums?

Riska novērtējums ir pamats veiksmīgai drošības un veselības pārvaldībai un galvenais faktors, kas mazina nelaimes gadījumus darbā un arodslimības. Ja tas tiek veiksmīgi īstenots, tas var uzlabot drošību un veselības aizsardzību darba vietā, kā arī darbības rādītājus kopumā.

Darba ņēmēju drošība un veselība Eiropā tiek aizsargāta, novērtējot un pārvaldot riskus darbā. Darba devējiem ir juridisks pienākums nodrošināt darba ņēmēju drošību un veselības aizsardzību visos ar darbu saistītajos aspektos un veikt riska novērtējumu. Tāpēc katram uzņēmumam ir jāveic riska novērtējums un jāizstrādā rīcības plāns. Lai veiktu efektīvu darba vietas riska novērtējumu, visiem iesaistītajiem dalībniekiem ir jābūt skaidrai izpratnei par:

- juridisko kontekstu un jēdzieniem,
- risku novērtēšanas procesu,
- galveno procesā iesaistīto dalībnieku lomu.

Darba ņēmējiem un/vai viņu pārstāvjiem ir tiesības saņemt informāciju par pasākumiem riska novērtējuma veikšanai un piedalīties riska novērtējumā.

Plašāka informācija par riska novērtējumu un darba ņēmēju un/vai viņu pārstāvju piedalīšanos riska novērtēšanas procesā ir pieejama OiRA projekta tīmekļa vietnē.

## Kas ir OiRA?

OiRA (Online Interactive Risk Assessment) ir tiešsaistes interaktīvais riska novērtējums. Tā ir tīmekļa lietojumprogramma, kas ļauj veikt drošības un veselības riska novērtējumu darba vietā.

## Kam OiRA ir paredzēts?

Ikviens var izmantot OiRA, lai novērtētu ar drošību un veselību saistītos riskus, kādi varētu būt darba vietā.

Tomēr OiRA ir veidots tā, lai tas būtu vislietderīgākais mazākiem uzņēmumiem. OiRA ir īpaši izveidots, lai palīdzētu tiem novērtēt riskus darbā un sagatavot dokumentētu riska novērtējumu, ietverot rīcības plānu, kas pielāgots uzņēmuma prasībām.

## Kas man jādara?

OiRA riska novērtēšanas procesā ir jāveic vairāki soļi.

- Sagatavošanās: dažiem rīkiem ir profila jautājumi, kas palīdz pielāgot rīku jūsu uzņēmuma specifikai. Kad atbildat uz profila jautājumiem, rīks pielāgojas jūsu konkrētajai situācijai un parāda piemērojamos moduļus.

- Iesaiste: katrs riska novērtējums ir jāveic, aktīvi iesaistoties darba ņēmējiem. Rīks ļauj izdrukāt pilnu riska novērtējuma tekstu vai tā daļas, lai informētu darba ņēmējus un saņemtu viņu atsauksmes.

- Riska identifikācija: OiRA parāda vairākus iespējamos drošības un veselības apdraudējumus vai problēmas, kas varētu pastāvēt jūsu darba vietā. Atbildot uz apgalvojumiem/jautājumiem ar “jā” vai “nē”, jūs norādāt, vai šādi apdraudējumi vai problēmas pastāv. Jūs varat arī nolemt neatbildēt uz jautājumu un atlikt atbildes sniegšanu uz vēlāku laiku.

- Novērtējums: daži rīki aicina jūs sarindot pēc prioritātes jūsu identificētos riskus. Ir dažādi veidi, kā to izdarīt, un tas ir atkarīgs no lēmumiem, ko pieņem mūsu valsts OiRA partneri / rīka izstrādātāji, un to īpašās pieejas. Daži rīki arī automātiski piešķir prioritāti riskiem, un jūs varat atcelt šīs prioritātes.

- Rīcības plāns: attiecībā uz katru identificēto risku rīks aicina jūs izlemt par vienu vai vairākiem pasākumiem riska novēršanai vai mazināšanai. Lielākā daļa rīku jums piedāvās dažus pasākumus. Jūs varat arī vienmēr izvēlēties ierakstīt savus pasākumus.

- Ziņojums: jums ir juridisks pienākums dokumentēt savu riska novērtējumu. Ziņojumu sadaļā atradīsiet dažādus ziņojumus, kas palīdzēs izsekot jūsu riska novērtējumam un sekot līdzi darbībām/pasākumiem, kurus esat nolēmis īstenot, lai novērstu vai mazinātu identificētos riskus.

## Cik ilgu laiku tas aizņems?

Nav iespējams noteikt, cik ilgs laiks parasti būs vajadzīgs novērtējumam, jo rīki atšķiras atkarībā no nozares un valsts.

Tomēr jūs varat atvēlēt novērtējumam tik daudz laika, cik jums ir, un vēlāk ērtā laikā atgriezties pie tā un atsākt no vietas, kur beidzāt.

## Kāpēc man jāreģistrējas?

Pirmais, ko jums lūgs darīt, sākot savu pirmo riska novērtējumu, ir izveidot OiRA kontu — tas ir vienkāršs un ātrs process.

Reģistrēšanās ļauj jums jebkurā laikā vienkārši pieteikties, lai turpinātu iepriekšējos novērtējumus vai sāktu jaunus.

Ja esat reģistrēts lietotājs, jums ir arī iespēja jebkurā laikā saņemt drukātu, precīzu un atjauninātu riska novērtējumu.

## Vai man ir jāsagatavojas?

Nav vajadzīga īpaša sagatavošanās, lai sāktu izmantot rīku, tomēr jums ir jāatvēl pietiekams laiks, lai apdomātu, kurš veiks riska novērtējumu un kā šajā procesā tiks iesaistīti darba ņēmēji.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More